OC.L10N.register(
    "sharebymail",
    {
    "Shared with %1$s" : "Delt med %1$s",
    "Shared with {email}" : "Delt med {email}",
    "Shared with %1$s by %2$s" : "Delt med %1$s af %2$s",
    "Shared with {email} by {actor}" : "Delt med {email} af {actor}",
    "You shared %1$s with %2$s by mail" : "Du delte %1$s med %2$s via e-mail",
    "You shared {file} with {email} by mail" : "Du delte {file} med {email} via e-mail",
    "%3$s shared %1$s with %2$s by mail" : "%3$s delte %1$s med %2$s via e-mail",
    "{actor} shared {file} with {email} by mail" : "{actor} delte {file} med {email} via e-mail",
    "Sharing %s failed, this item is already shared with %s" : "Deling %s fejlede, dette objekt er allerede delt med %s",
    "Failed to send share by E-mail" : "Kunne ikke dele via e-mail",
    "%s shared »%s« with you" : "%s delt »%s« med dig",
    "%s shared »%s« with you on behalf of %s" : "%s delte »%s« med dig for %s",
    "%s shared »%s« with you." : "%s delte »%s« med dig.",
    "%s shared »%s« with you on behalf of %s." : "%s delte »%s« med dig på vegne af %s.",
    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
    "Open »%s«" : "Åbn »%s«",
    "Password to access »%s« shared to you by %s" : "Kodeord for adgang til »%s« delt med dig af %s",
    "Password to access »%s«" : "Kodeord for adgang til »%s«",
    "It is protected with the following password: %s" : "Det er beskyttet af følgende kodeord: %s",
    "Could not find share" : "Kan ikke finde deling",
    "Share by mail" : "Delt med mail",
    "Send password by mail" : "Send kodeord på mail",
    "Failed to create the E-mail" : "Oprettelse af e-mail mislykkedes",
    "Hey there,\n\n%s shared »%s« with you on behalf of %s.\n\n%s\n\n" : "Hej,\n\n%s delte »%s« med dig, for %s.\n\n%s\n\n",
    "Hey there,\n\n%s shared »%s« with you.\n\n%s\n\n" : "Hey there,\n\n%s delte »%s« med dig.\n\n%s\n\n",
    "Cheers!" : "Hej!",
    "Hey there,<br><br>%s shared <a href=\"%s\">%s</a> with you on behalf of %s.<br><br>" : "Hej,<br><br>%s delte <a href=\"%s\">%s</a> med dig, for %s.<br><br>",
    "Hey there,<br><br>%s shared <a href=\"%s\">%s</a> with you.<br><br>" : "Hej,<br><br>%s delte <a href=\"%s\">%s</a> med dig.<br><br>"
},
"nplurals=2; plural=(n != 1);");
